<?php
/**
 * Viral Blog functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Viral_Blog
 */

if ( ! function_exists( 'viral_blog_setup' ) ) :

    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function viral_blog_setup() {
        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on Viral Blog, use a find and replace
         * to change 'viral-blog' to the name of your theme in all the template files.
         */
        load_theme_textdomain( 'viral-blog');

        // Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support( 'title-tag' );

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support( 'post-thumbnails', array( 'post', 'page', 'menu' ) );

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus( array(
            'primary' => esc_html__( 'Primary', 'viral-blog' ),
            'secondary' => esc_html__( 'Footer', 'viral-blog' ),
        ) );

         // Editor style (editor-style.css)
        add_editor_style( array( 'assets/css/editor-style.css' ) );

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support( 'html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ) );

        // Set up the WordPress core custom background feature.
        add_theme_support( 'custom-background', apply_filters( 'viral_blog_custom_background_args', array(
            'default-color' => 'ffffff',
            'default-image' => '',
        ) ) );

        // Add theme support for selective refresh for widgets.
        add_theme_support( 'customize-selective-refresh-widgets' );

        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support( 'custom-logo', array(
            'height'      => 400,
            'width'       => 100,
            'flex-width'  => true,
            'flex-height' => true,
        ) );
    }
endif;
add_action( 'after_setup_theme', 'viral_blog_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function viral_blog_content_width() {
    // This variable is intended to be overruled from themes.
    // Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
    // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
    $GLOBALS['content_width'] = apply_filters( 'viral_blog_content_width', 1370 );
}
add_action( 'after_setup_theme', 'viral_blog_content_width', 0 );


require( trailingslashit( get_template_directory() ) . 'inc/navwalker.php' );


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
    require get_template_directory() . '/inc/jetpack.php';
}

function viral_blog_widgets_setup() {
    global $viral_blog_options;
    // Widget areas
    if ( function_exists( 'register_sidebar' ) ) :
        // Sidebar right
        register_sidebar( array(
            'name'          => __( "Post Sidebar Widget Here", 'viral-blog' ),
            'id'            => "viral-blog-post-sidebar",
            'description'   => __( 'Widgets placed here will display in the post detail page', 'viral-blog' ),
            'before_widget' => '<div id="%1$s" class="widget %2$s viral-blog-sidebar-widget">',
            'after_widget'  => '</div>',
            'before_title'  => '<h3 class="tbeer-sidebar-widget-title">',
            'after_title'   => '</h3>'
        ) );

        register_sidebar( array(
            'name'          => __( "Advertizement Widget Here", 'viral-blog' ),
            'id'            => "viral-blog-widgets-sidebar",
            'description'   => __( 'Widgets placed here will display in the right sidebar', 'viral-blog' ),
            'before_widget' => '<div id="%1$s" class="widget %2$s tbeer-addvertisment-space tbeer-sidebar-widget">',
            'after_widget'  => '</div>',
            'before_title'  => '<h3 class="tbeer-sidebar-widget-title">',
            'after_title'   => '</h3>'
        ) );
        register_sidebar( array(
            'name'          => __( "Sidebar Widget Here", 'viral-blog' ),
            'id'            => "viral-blog-trending-sidebar",
            'description'   => __( 'Sidebar for trending posts', 'viral-blog' ),
            'before_widget' => '<div id="%1$s" class="widget %2$s tbeer-sidebar-widget tbeer-trending-news-widget">',
            'after_widget'  => '</div>',
            'before_title'  => '<h3 class="tbeer-sidebar-widget-title">',
            'after_title'   => '</h3>'
        ) );
        register_sidebar( array(
            'name'          => __( "Featured Widget Here", 'viral-blog' ),
            'id'            => "viral-blog-banner-sidebar",
            'description'   => __( 'Sidebar for Banner posts', 'viral-blog' ),
            'before_widget' => '<div id="%1$s" class="widget %2$s featured-widget">',
            'after_widget'  => '</div>',
            'before_title'  => '<header class="heading"><h2>',
            'after_title'   => '</h2></header>'
        ) );
        register_sidebar( array(
            'name'          => "Footer Block Widgets Here",
            'id'            => "viral-blog-widgets-footer-block-1",
            'description'   => __( 'Widgets placed here will display in the footer block', 'viral-blog' ),
            'before_widget' => '<div class="col-md-3 col-sm-6 col-xs-12"><div id="%1$s" class="widget %2$s tbeer-footer-widget tbeer-links-widget">',
            'after_widget'  => '</div></div>',
            'before_title'  => '<h3 class="tbeer-footer-widget-title">',
            'after_title'   => '</h3>'
        ) );
    endif;
}

add_action( 'widgets_init', 'viral_blog_widgets_setup' );


function viral_blog_load_theme_assets() {

    // Google Font
    wp_enqueue_style( 'google-font', 'https://fonts.googleapis.com/css?family=Montserrat:400,700%7CRaleway:400,500', array());
    wp_enqueue_style( 'google-font-1', 'https://fonts.googleapis.com/css?family=Merriweather', array());    
    // Enqueue all the theme CSS
    wp_enqueue_style( 'viral-blog-main-style', get_template_directory_uri() . '/assets/css/style.css' );
    wp_enqueue_style( 'viral-blog-style', get_stylesheet_uri() );

    // Enqueue all the js files of theme
    wp_enqueue_script( 'viral_blog_plugins-js', get_template_directory_uri() . '/assets/js/plugins.js', array('jquery'), false, true );
    wp_enqueue_script( 'viral_blog_jquery-main', get_template_directory_uri() . '/assets/js/main.js', array('jquery'), false, true );

    
}

add_action( 'wp_enqueue_scripts', 'viral_blog_load_theme_assets' );
// Enqueue comment-reply script if comments_open and singular
function viral_blog_enqueue_comment_reply() {
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
}

add_action( 'wp_enqueue_scripts', 'viral_blog_enqueue_comment_reply' );
add_filter( 'nav_menu_css_class', 'viral_blog_special_nav_class', 10, 2 );
function viral_blog_special_nav_class( $classes, $item ) {
    if ( in_array( 'current-menu-item', $classes ) ) {
        $classes[] = 'active ';
    }
    global $viral_blog_options;

    return $classes;
}



function viral_blog_comment( $comment, $args, $depth ) {
    extract( $args, EXTR_SKIP );
    ?>
    <li <?php comment_class( empty( $args['has_children'] ) ? 'tbeer-comments tbeer-replied-comment' : 'tbeer-comments' ) ?>
    id="comment-<?php comment_ID() ?>">
    <div class="tbeer-user-img">
        <img class="img-circle media-object"
        src="<?php echo esc_url(get_avatar_url( get_avatar( $comment, $args['avatar_size'] ) )); ?>"
        alt="Author avatar">
    </div>
    <div class="tbeer-comment-details">
        <?php if ( $depth > 1 ): echo '<div class="media">';
            else : echo '<div class="media-body">'; endif; ?>
            <h3><a href="#!"><?php echo get_comment_author_link(); ?></a>
                <span class="tbeer-comment-time"><?php
                /* translators: 1: date, 2: time */
                echo esc_html(human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) )) . ' ago'; ?></a><?php edit_comment_link( __( '(Edit)', 'viral-blog' ), '  ', '' );
                ?>
            </span>
        </h3>
        <p><?php comment_text(); ?></p>
        <div class="reply-box tbeer-comment-reply"><?php comment_reply_link( array_merge( $args, array(
            'reply_text' => 'Reply',
            'depth'      => $depth,
            'max_depth'  => $args['max_depth']
            ) ) ) ?></div>
            <div class="comment-block">
                <?php if ( $comment->comment_approved == '0' ) : ?>
                    <em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'viral-blog' ); ?></em>
                    <br/>
                <?php endif; ?>
            </div>
        </div>
    </li>
    <?php
}

add_filter( 'comment_form_fields', 'viral_blog_move_comment_field' );
function viral_blog_move_comment_field( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;

    return $fields;
}

if ( ! function_exists( 'viral_blog_load_widgets' ) ) :
    /**
     * Load widgets.
     *
     * @since 1.0.0
     */
    function viral_blog_load_widgets() {
        // Advanced Recent Posts widget.
        register_widget( 'viral_blog_Recent_Posts_Widget' );
    }
endif;
add_action( 'widgets_init', 'viral_blog_load_widgets' );
/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/aq_resizer.php';
if ( ! class_exists( 'viral_blog_Recent_Posts_Widget' ) ) :
    /**
     * Advanced Recent Posts Widget Class
     *
     * @since 1.0.0
     */
    class Viral_Blog_Recent_Posts_Widget extends WP_Widget {
        /**
         * Constructor.
         *
         * @since 1.0.0
         */
        function __construct() {
            $opts = array(
                'classname'   => 'viral_blog_advanced_recent_posts',
                'description' => __( 'Featured Post Widget. Displays recent posts with thumbnail.', 'viral-blog' ),
            );
            parent::__construct( 'viral-blog-advanced-recent-posts', __( 'Viral Blog: Featured Posts', 'viral-blog' ), $opts );
        }

        /**
         * Echo the widget content.
         *
         * @since 1.0.0
         *
         * @param array $args Display arguments including before_title, after_title,
         *                        before_widget, and after_widget.
         * @param array $instance The settings for the particular instance of the widget.
         */
        function widget( $args, $instance ) {
            $title         = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
            $post_category = ! empty( $instance['post_category'] ) ? intval( $instance['post_category'] ) : 0;
            echo $args['before_widget'];

            if ( $post_category == 0 ) {

                $header_args = array(
                    'post_type'      => 'post',
                    'posts_per_page' => 5,
                    'orderby'        => 'date',
                    'order'          => 'DESC',
                );

            } elseif ( $post_category > 0 ) {
                $header_args = array(
                    'post_type'      => 'post',
                    'posts_per_page' => 5,
                    'orderby'        => 'date',
                    'order'          => 'DESC',
                    'cat'            => $post_category,
                );
            } else {
                $header_args = array(
                    'post_type'      => 'post',
                    'posts_per_page' => 5,
                    'orderby'        => 'date',
                    'order'          => 'DESC',
                    'meta_query'     => array(
                        array(
                            'key'     => '_viral_blog_featured',
                            'value'   => 'on',
                            'compare' => '=',
                        ),
                    ),
                );
            }
            $header_query = new WP_Query( $header_args );
            if ( $header_query->have_posts() ):$i = 1;
                echo ' <!-- FEATURED NEWS SECTION -->
                <section class="tbeer-featured-news-section fs-image">
                <div class="container">
                <div class="row">
                ';
                while ( $header_query->have_posts() ):
                    $header_query->the_post(); ?>
                    <?php
                    $thumbnail      = get_post_thumbnail_id();
                    $img_url        = wp_get_attachment_image_src( $thumbnail, 'full' );
                    $alt            = get_post_meta( $thumbnail, '_wp_attachment_image_alt', true );
                    $w              = ( $i == 1 ) ? "1170" : "250";
                    $h              = ( $i == 1 ) ? "500" : "250";
                    $featured_class = ( $i == 1 ) ? "tbeer-main-featured-post" : "tbeer-other-featured-post-wrapper";
                    if ( $img_url ) {

                        $url = aq_resize( $img_url[0], $width = $w, $height = $h, $crop = true, $single = true, $upscale = false );
                    } else {
                        $url = get_template_directory_uri() . '/assets/images/no-image.png';
                        $alt = "No Image";
                    }
                    if ( $i <= 2 ) {
                        echo '<div class="' . esc_attr($featured_class) . '">';
                    }
                    if ( $i > 1 )
                        echo '<div class="tbeer-featured-post">' ?>
                    <div class="tbeer-image-wrapper repeatImg">
                        <img src="<?php echo esc_url($url) ; ?>" alt="<?php echo esc_attr( $alt ); ?>">
                    </div>
                    <div class="tbeer-featured-post-details">
                        <?php if ( $i == 1 ): ?>
                            <div
                            class="tbeer-category-meta"> <?php if ( get_the_category() ) : ?><?php the_category( ' / ' );endif; ?></div>
                        <?php endif; ?>
                        <h3 class="tbeer-featured-post-heading">
                            <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                        </h3>
                        <?php if ( $i == 1 ): ?>
                            <div class="tbeer-featured-post-meta">
                                <span class="tbeer-featured-post-date"><?php echo esc_html(date( "m.d.y" )); ?></span>
                                <?php the_author_posts_link(); ?>
                            </div>
                        <?php endif; ?>
                    </div>
                    <?php echo '</div>';
                    $i ++;
                endwhile;
                if ( $i > 1 ) {
                    echo '</div>';
                }
                echo '</div>
                </div>
                </section>';
            endif;
            wp_reset_postdata();
            ?>
            <?php
            echo $args['after_widget'];
        }

        /**
         * Update widget instance.
         *
         * @since 1.0.0
         *
         * @param array $new_instance New settings for this instance as input by the user via
         *                            {@see WP_Widget::form()}.
         * @param array $old_instance Old settings for this instance.
         *
         * @return array Settings to save or bool false to cancel saving.
         */
        function update( $new_instance, $old_instance ) {
            $instance                  = $old_instance;
            $instance['title']         = sanitize_text_field( $new_instance['title'] );
            $instance['post_category'] = intval( $new_instance['post_category'] );

            return $instance;
        }

        /**
         * Output the settings update form.
         *
         * @since 1.0.0
         *
         * @param array $instance Current settings.
         */
        function form( $instance ) {
            // Defaults.
            $instance      = wp_parse_args( (array) $instance, array(
                'title'         => '',
                'post_category' => '',
            ) );
            $title         = esc_attr( $instance['title'] );
            $post_category = intval( $instance['post_category'] );
            ?>
            <p>
                <label
                for="<?php echo esc_attr( $this->get_field_id( 'post_category' ) ); ?>"><?php esc_html_e( 'Select Category:', 'viral-blog' ); ?></label>
                <?php
                $cat_args = array(
                    'orderby'          => 'name',
                    'hide_empty'       => 0,
                    'taxonomy'         => 'category',
                    'name'             => $this->get_field_name( 'post_category' ),
                    'id'               => $this->get_field_id( 'post_category' ),
                    'selected'         => $post_category,
                    'show_option_all'  => __( 'Latest posts', 'viral-blog' ),
                    'show_option_none' => __( 'Featured', 'viral-blog' ),
                );
                wp_dropdown_categories( $cat_args );
                ?>
            </p>
            <?php
        }
    }
endif;